@@ -40,7 +40,7 @@ def save_state(model, best_acc):
             state['state_dict'][key.replace('module.', '')] = \
                 state['state_dict'].pop(key)
     if args.model_type == 0:
-        if args.bn_fuse == 1:
+        if args.bn_fuse:
             if args.prune_quant or args.prune_qaft:
                 torch.save({'cfg': cfg, 'best_acc': best_acc,
                             'state_dict': state['state_dict']}, 'models_save/nin_bn_fused.pth')
@@ -53,7 +53,7 @@ def save_state(model, best_acc):
             else:
                 torch.save(state, 'models_save/nin.pth')
     else:
-        if args.bn_fuse == 1:
+        if args.bn_fuse:
             if args.prune_quant or args.prune_qaft:
                 torch.save({'cfg': cfg, 'best_acc': best_acc,
                             'state_dict': state['state_dict']}, 'models_save/nin_gc_bn_fused.pth')
@@ -87,7 +87,7 @@ def train(epoch):
         loss = criterion(output, target)
 
         # PTQ doesn't need backward
-        if not args.ptq:
+        if not args.ptq_control:
             optimizer.zero_grad()
             loss.backward()
             optimizer.step()
@@ -166,8 +166,11 @@ if __name__ == '__main__':
     parser.add_argument('--w_bits', type=int, default=8)
     parser.add_argument('--a_bits', type=int, default=8)
     # bn融合标志位
-    parser.add_argument('--bn_fuse', type=int, default=0,
-                        help='bn_fuse:1')
+    parser.add_argument('--bn_fuse', action='store_true',
+                        help='batch-normalization fuse')
+    # bn融合校准标志位
+    parser.add_argument('--bn_fuse_calib', action='store_true',
+                        help='batch-normalization fuse calibration')
     # 量化方法选择
     parser.add_argument('--q_type', type=int, default=0,
                         help='quant_type:0-symmetric, 1-asymmetric')
@@ -186,9 +189,12 @@ if __name__ == '__main__':
     # prune_qaft
     parser.add_argument('--prune_qaft', default='', type=str, metavar='PATH',
                         help='the path to the prune_qaft model')
-    # ptq标志位
+    # ptq_observer
     parser.add_argument('--ptq', action='store_true',
                         help='post-training-quantization')
+    # ptq_control
+    parser.add_argument('--ptq_control', action='store_true',
+                        help='ptq control flag')
     # ptq_percentile
     parser.add_argument('--percentile', type=float, default=0.999999,
                         help='the percentile of ptq')
@@ -249,6 +255,7 @@ if __name__ == '__main__':
                          q_level=args.q_level, device=device,
                          weight_observer=args.weight_observer,
                          bn_fuse=args.bn_fuse,
+                         bn_fuse_calib=args.bn_fuse_calib,
                          pretrained_model=args.pretrained_model,
                          qaft=args.qaft,
                          ptq=args.ptq,
@@ -269,6 +276,7 @@ if __name__ == '__main__':
                          q_level=args.q_level, device=device,
                          weight_observer=args.weight_observer,
                          bn_fuse=args.bn_fuse,
+                         bn_fuse_calib=args.bn_fuse_calib,
                          pretrained_model=args.pretrained_model,
                          qaft=args.qaft,
                          ptq=args.ptq,
@@ -292,6 +300,7 @@ if __name__ == '__main__':
                          q_level=args.q_level, device=device,
                          weight_observer=args.weight_observer,
                          bn_fuse=args.bn_fuse,
+                         bn_fuse_calib=args.bn_fuse_calib,
                          pretrained_model=args.pretrained_model,
                          qaft=args.qaft,
                          ptq=args.ptq,
@@ -311,6 +320,7 @@ if __name__ == '__main__':
                          q_level=args.q_level, device=device,
                          weight_observer=args.weight_observer,
                          bn_fuse=args.bn_fuse,
+                         bn_fuse_calib=args.bn_fuse_calib,
                          pretrained_model=args.pretrained_model,
                          qaft=args.qaft,
                          ptq=args.ptq,
@@ -340,6 +350,7 @@ if __name__ == '__main__':
                          q_level=args.q_level, device=device,
                          weight_observer=args.weight_observer,
                          bn_fuse=args.bn_fuse,
+                         bn_fuse_calib=args.bn_fuse_calib,
                          pretrained_model=args.pretrained_model,
                          qaft=args.qaft,
                          ptq=args.ptq,
@@ -359,12 +370,12 @@ if __name__ == '__main__':
     criterion = nn.CrossEntropyLoss()
     optimizer = optim.Adam(params, lr=base_lr, weight_decay=args.wd)
 
-    if args.ptq:
+    if args.ptq_control:
         args.end_epochs = 2
         print('ptq is doing...')
     for epoch in range(args.start_epochs, args.end_epochs):
         adjust_learning_rate(optimizer, epoch)
         train(epoch)
         test()
-    if args.ptq:
+    if args.ptq_control:
         print('ptq is done')
